import express from 'express';
import { PrismaClient } from '@prisma/client';

const router = express.Router();
const prisma = new PrismaClient();

// Créer un nouveau bloc
router.post('/', async (req, res) => {
  try {
    const { type, content, pageId, userId, order } = req.body;

    const block = await prisma.block.create({
      data: {
        type,
        content,
        pageId,
        userId,
        order
      }
    });

    res.status(201).json(block);
  } catch (error) {
    console.error('Erreur lors de la création du bloc:', error);
    res.status(500).json({ message: 'Erreur lors de la création du bloc' });
  }
});

// Mettre à jour un bloc
router.put('/:id', async (req, res) => {
  try {
    const { id } = req.params;
    const { content, type, order } = req.body;

    const block = await prisma.block.update({
      where: { id },
      data: {
        content,
        type,
        order
      }
    });

    res.json(block);
  } catch (error) {
    console.error('Erreur lors de la mise à jour du bloc:', error);
    res.status(500).json({ message: 'Erreur lors de la mise à jour du bloc' });
  }
});

// Supprimer un bloc
router.delete('/:id', async (req, res) => {
  try {
    const { id } = req.params;

    await prisma.block.delete({
      where: { id }
    });

    res.status(204).send();
  } catch (error) {
    console.error('Erreur lors de la suppression du bloc:', error);
    res.status(500).json({ message: 'Erreur lors de la suppression du bloc' });
  }
});

// Obtenir tous les blocs d'une page
router.get('/page/:pageId', async (req, res) => {
  try {
    const { pageId } = req.params;

    const blocks = await prisma.block.findMany({
      where: { pageId },
      orderBy: { order: 'asc' }
    });

    res.json(blocks);
  } catch (error) {
    console.error('Erreur lors de la récupération des blocs:', error);
    res.status(500).json({ message: 'Erreur lors de la récupération des blocs' });
  }
});

export default router; 