import express from 'express';
import { PrismaClient } from '@prisma/client';

const router = express.Router();
const prisma = new PrismaClient();

// Créer une nouvelle page
router.post('/', async (req, res) => {
  try {
    const { title, content, userId, parentId } = req.body;

    const page = await prisma.page.create({
      data: {
        title,
        content,
        userId,
        parentId
      },
      include: {
        user: {
          select: {
            id: true,
            name: true
          }
        }
      }
    });

    res.status(201).json(page);
  } catch (error) {
    res.status(500).json({ message: 'Erreur lors de la création de la page' });
  }
});

// Obtenir toutes les pages d'un utilisateur
router.get('/user/:userId', async (req, res) => {
  try {
    const { userId } = req.params;
    
    const pages = await prisma.page.findMany({
      where: {
        userId
      },
      include: {
        user: {
          select: {
            id: true,
            name: true
          }
        }
      }
    });

    res.json(pages);
  } catch (error) {
    res.status(500).json({ message: 'Erreur lors de la récupération des pages' });
  }
});

// Obtenir une page spécifique
router.get('/:id', async (req, res) => {
  try {
    const { id } = req.params;
    
    const page = await prisma.page.findUnique({
      where: { id },
      include: {
        user: {
          select: {
            id: true,
            name: true
          }
        },
        blocks: true
      }
    });

    if (!page) {
      return res.status(404).json({ message: 'Page non trouvée' });
    }

    res.json(page);
  } catch (error) {
    res.status(500).json({ message: 'Erreur lors de la récupération de la page' });
  }
});

// Mettre à jour une page
router.put('/:id', async (req, res) => {
  try {
    const { id } = req.params;
    const { title, content } = req.body;

    const page = await prisma.page.update({
      where: { id },
      data: {
        title,
        content
      }
    });

    res.json(page);
  } catch (error) {
    res.status(500).json({ message: 'Erreur lors de la mise à jour de la page' });
  }
});

// Supprimer une page
router.delete('/:id', async (req, res) => {
  try {
    const { id } = req.params;

    await prisma.page.delete({
      where: { id }
    });

    res.status(204).send();
  } catch (error) {
    res.status(500).json({ message: 'Erreur lors de la suppression de la page' });
  }
});

export default router; 